@@ -23,18 +23,18 @@ class Tracker(RTResource):
         """:return: An instance of :py:class:`rtkit.entities.Ticket`"""
         return self._get_entity(Ticket, value)
 
-    def search_tickets(self, query, order):
+    def search_tickets(self, query, order=None):
         """Search tickets
-
-           .. warning:: Not yet Implemented
+           :return: A list of :py:class:`rtkit.entities.Ticket` instances
         """
         content = {'query': query, 'format': 'l'}
+        if order:
+            content['orderby'] = order
         req = urllib2.Request(
             url=self.auth.url + 'search/ticket',
             data=urllib.urlencode(content),
         )
         response = self.response_cls(req, self.auth.open(req))
-        #response = self.post('search/ticket', {'content':content})
         tickets = [Ticket(tracker=self, **dict(d)) for d in response.parsed]
         return tickets
 
